==> openflowplugin-extension-nicira-0.7.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/dst/choice/grouping/dst/choice/DstNxArpShaCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.dst.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link DstNxArpShaCaseBuilder} instances.
 *
 * @see DstNxArpShaCaseBuilder
 *
 */
public class DstNxArpShaCaseBuilder implements Builder<DstNxArpShaCase> {

    private Boolean _nxArpSha;


    Map<Class<? extends Augmentation<DstNxArpShaCase>>, Augmentation<DstNxArpShaCase>> augmentation = Collections.emptyMap();

    public DstNxArpShaCaseBuilder() {
    }
    public DstNxArpShaCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxArpShaGrouping arg) {
        this._nxArpSha = arg.isNxArpSha();
    }

    public DstNxArpShaCaseBuilder(DstNxArpShaCase base) {
        this._nxArpSha = base.isNxArpSha();
        if (base instanceof DstNxArpShaCaseImpl) {
            DstNxArpShaCaseImpl impl = (DstNxArpShaCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<DstNxArpShaCase>>, Augmentation<DstNxArpShaCase>> aug =((AugmentationHolder<DstNxArpShaCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxArpShaGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxArpShaGrouping) {
            this._nxArpSha = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxArpShaGrouping)arg).isNxArpSha();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxArpShaGrouping]");
    }

    public Boolean isNxArpSha() {
        return _nxArpSha;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<DstNxArpShaCase>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public DstNxArpShaCaseBuilder setNxArpSha(final Boolean value) {
        this._nxArpSha = value;
        return this;
    }
    
    public DstNxArpShaCaseBuilder addAugmentation(Class<? extends Augmentation<DstNxArpShaCase>> augmentationType, Augmentation<DstNxArpShaCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public DstNxArpShaCaseBuilder removeAugmentation(Class<? extends Augmentation<DstNxArpShaCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public DstNxArpShaCase build() {
        return new DstNxArpShaCaseImpl(this);
    }

    private static final class DstNxArpShaCaseImpl implements DstNxArpShaCase {
    
        private final Boolean _nxArpSha;
    
        private Map<Class<? extends Augmentation<DstNxArpShaCase>>, Augmentation<DstNxArpShaCase>> augmentation = Collections.emptyMap();
    
        DstNxArpShaCaseImpl(DstNxArpShaCaseBuilder base) {
            this._nxArpSha = base.isNxArpSha();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<DstNxArpShaCase> getImplementedInterface() {
            return DstNxArpShaCase.class;
        }
    
        @Override
        public Boolean isNxArpSha() {
            return _nxArpSha;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<DstNxArpShaCase>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxArpSha);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!DstNxArpShaCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            DstNxArpShaCase other = (DstNxArpShaCase)obj;
            if (!Objects.equals(_nxArpSha, other.isNxArpSha())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                DstNxArpShaCaseImpl otherImpl = (DstNxArpShaCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<DstNxArpShaCase>>, Augmentation<DstNxArpShaCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("DstNxArpShaCase");
            CodeHelpers.appendValue(helper, "_nxArpSha", _nxArpSha);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.7.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/dst/choice/grouping/dst/choice/DstNxArpShaCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.dst.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link DstNxArpShaCaseBuilder} instances.
 *
 * @see DstNxArpShaCaseBuilder
 *
 */
public class DstNxArpShaCaseBuilder implements Builder<DstNxArpShaCase> {

    private Boolean _nxArpSha;


    Map<Class<? extends Augmentation<DstNxArpShaCase>>, Augmentation<DstNxArpShaCase>> augmentation = Collections.emptyMap();

    public DstNxArpShaCaseBuilder() {
    }
    public DstNxArpShaCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxArpShaGrouping arg) {
        this._nxArpSha = arg.isNxArpSha();
    }

    public DstNxArpShaCaseBuilder(DstNxArpShaCase base) {
        this._nxArpSha = base.isNxArpSha();
        if (base instanceof DstNxArpShaCaseImpl) {
            DstNxArpShaCaseImpl impl = (DstNxArpShaCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<DstNxArpShaCase>>, Augmentation<DstNxArpShaCase>> aug =((AugmentationHolder<DstNxArpShaCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxArpShaGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxArpShaGrouping) {
            this._nxArpSha = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxArpShaGrouping)arg).isNxArpSha();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxArpShaGrouping]");
    }

    public Boolean isNxArpSha() {
        return _nxArpSha;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<DstNxArpShaCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public DstNxArpShaCaseBuilder setNxArpSha(final Boolean value) {
        this._nxArpSha = value;
        return this;
    }
    
    public DstNxArpShaCaseBuilder addAugmentation(Class<? extends Augmentation<DstNxArpShaCase>> augmentationType, Augmentation<DstNxArpShaCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public DstNxArpShaCaseBuilder removeAugmentation(Class<? extends Augmentation<DstNxArpShaCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public DstNxArpShaCase build() {
        return new DstNxArpShaCaseImpl(this);
    }

    private static final class DstNxArpShaCaseImpl implements DstNxArpShaCase {
    
        private final Boolean _nxArpSha;
    
        private Map<Class<? extends Augmentation<DstNxArpShaCase>>, Augmentation<DstNxArpShaCase>> augmentation = Collections.emptyMap();
    
        DstNxArpShaCaseImpl(DstNxArpShaCaseBuilder base) {
            this._nxArpSha = base.isNxArpSha();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<DstNxArpShaCase> getImplementedInterface() {
            return DstNxArpShaCase.class;
        }
    
        @Override
        public Boolean isNxArpSha() {
            return _nxArpSha;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<DstNxArpShaCase>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxArpSha);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!DstNxArpShaCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            DstNxArpShaCase other = (DstNxArpShaCase)obj;
            if (!Objects.equals(_nxArpSha, other.isNxArpSha())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                DstNxArpShaCaseImpl otherImpl = (DstNxArpShaCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<DstNxArpShaCase>>, Augmentation<DstNxArpShaCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("DstNxArpShaCase");
            CodeHelpers.appendValue(helper, "_nxArpSha", _nxArpSha);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
